@@ -10,7 +10,7 @@
 //    - Technische Universität München, Lehrstuhl für Informatik mit
 //      Schwerpunkt Wissenschaftliches Rechnen ,
 //    - Fritz-Haber-Institut, Berlin, Abt. Theorie,
-//    - Max-Plack-Institut für Mathematik in den Naturwissenschaftrn,
+//    - Max-Plack-Institut für Mathematik in den Naturwissenschaften,
 //      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition,
 //      and
 //    - IBM Deutschland GmbH
@@ -89,7 +89,7 @@ static __forceinline void hh_trafo_complex_kernel_4_AVX_2hv(double complex* q, d
 static __forceinline void hh_trafo_complex_kernel_2_AVX_2hv(double complex* q, double complex* hh, int nb, int ldq, int ldh, double complex s);
 
 /*
-!f>#ifdef HAVE_AVX
+!f>#if defined(HAVE_AVX) || defined(HAVE_AVX2)
 !f> interface
 !f>   subroutine double_hh_trafo_complex_avx_avx2_2hv(q, hh, pnb, pnq, pldq, pldh) bind(C, name="double_hh_trafo_complex_avx_avx2_2hv")
 !f>     use, intrinsic :: iso_c_binding
@@ -115,29 +115,31 @@ void double_hh_trafo_complex_avx_avx2_2hv(double complex* q, double complex* hh,
 		s += hh[i-1] * conj(hh[(i+ldh)]);
 	}
 
-#if 1
+//#if 1
 	for (i = 0; i < nq-4; i+=8)
 	{
 		hh_trafo_complex_kernel_8_AVX_2hv(&q[i], hh, nb, ldq, ldh, s);
 	}
-	if (nq-i > 0)
+	if (nq-i == 0) {
+          return;
+	} else
 	{
 		hh_trafo_complex_kernel_4_AVX_2hv(&q[i], hh, nb, ldq, ldh, s);
 	}
-#else
-	for (i = 0; i < nq-4; i+=6)
-	{
-		hh_trafo_complex_kernel_6_AVX_2hv(&q[i], hh, nb, ldq, ldh, s);
-	}
-	if (nq-i > 2)
-	{
-		hh_trafo_complex_kernel_4_AVX_2hv(&q[i], hh, nb, ldq, ldh, s);
-	}
-	else if (nq-i > 0)
-	{
-		hh_trafo_complex_kernel_2_AVX_2hv(&q[i], hh, nb, ldq, ldh, s);
-	}
-#endif
+//#else
+//	for (i = 0; i < nq-4; i+=6)
+//	{
+//		hh_trafo_complex_kernel_6_AVX_2hv(&q[i], hh, nb, ldq, ldh, s);
+//	}
+//	if (nq-i > 2)
+//	{
+//		hh_trafo_complex_kernel_4_AVX_2hv(&q[i], hh, nb, ldq, ldh, s);
+//	}
+//	else if (nq-i > 0)
+//	{
+//		hh_trafo_complex_kernel_2_AVX_2hv(&q[i], hh, nb, ldq, ldh, s);
+//	}
+//#endif
 }
 
 static __forceinline void hh_trafo_complex_kernel_8_AVX_2hv(double complex* q, double complex* hh, int nb, int ldq, int ldh, double complex s)
@@ -443,7 +445,7 @@ static __forceinline void hh_trafo_complex_kernel_8_AVX_2hv(double complex* q, d
 	q1 = _mm256_add_pd(q1, _mm256_addsub_pd( _mm256_mul_pd(h2_real, y1), _mm256_shuffle_pd(tmp1, tmp1, 0x5)));
 #endif
 	tmp2 = _mm256_mul_pd(h2_imag, y2);
-#ifdef __FMA4_
+#ifdef __ELPA_USE_FMA_
 	q2 = _mm256_add_pd(q2, _mm256_FMADDSUB_pd(h2_real, y2, _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
 #else
 	q2 = _mm256_add_pd(q2, _mm256_addsub_pd( _mm256_mul_pd(h2_real, y2), _mm256_shuffle_pd(tmp2, tmp2, 0x5)));
