@@ -10,7 +10,7 @@
 //    - Technische Universität München, Lehrstuhl für Informatik mit
 //      Schwerpunkt Wissenschaftliches Rechnen ,
 //    - Fritz-Haber-Institut, Berlin, Abt. Theorie,
-//    - Max-Plack-Institut für Mathematik in den Naturwissenschaftrn,
+//    - Max-Plack-Institut für Mathematik in den Naturwissenschaften,
 //      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition,
 //      and
 //    - IBM Deutschland GmbH
@@ -102,13 +102,17 @@ void single_hh_trafo_complex_sse_1hv(double complex* q, double complex* hh, int*
 	{
 		hh_trafo_complex_kernel_6_SSE_1hv(&q[i], hh, nb, ldq);
 	}
-	if (nq-i > 2)
-	{
+	if (nq-i == 0) {
+	  return;
+	} else {
+	  if (nq-i > 2)
+	  {
 		hh_trafo_complex_kernel_4_SSE_1hv(&q[i], hh, nb, ldq);
-	}
-	else if (nq-i > 0)
-	{
+	  }
+	  else
+	  {
 		hh_trafo_complex_kernel_2_SSE_1hv(&q[i], hh, nb, ldq);
+	  }
 	}
 }
 
