@@ -10,7 +10,7 @@
 //    - Technische Universität München, Lehrstuhl für Informatik mit
 //      Schwerpunkt Wissenschaftliches Rechnen ,
 //    - Fritz-Haber-Institut, Berlin, Abt. Theorie,
-//    - Max-Plack-Institut für Mathematik in den Naturwissenschaftrn,
+//    - Max-Plack-Institut für Mathematik in den Naturwissenschaften,
 //      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition,
 //      and
 //    - IBM Deutschland GmbH
@@ -104,25 +104,25 @@ void double_hh_trafo_complex_sse_2hv(double complex* q, double complex* hh, int*
 		s += hh[i-1] * conj(hh[(i+ldh)]);
 	}
 
-#if 1
+//#if 1
 	for (i = 0; i < nq; i+=4)
 	{
 		hh_trafo_complex_kernel_4_SSE_2hv(&q[i], hh, nb, ldq, ldh, s);
 	}
-#else
-	for (i = 0; i < nq-2; i+=3)
-	{
-		hh_trafo_complex_kernel_3_SSE_2hv(&q[i], hh, nb, ldq, ldh, s);
-	}
-	if (nq-i > 1)
-	{
-		hh_trafo_complex_kernel_2_SSE_2hv(&q[i], hh, nb, ldq, ldh, s);
-	}
-	else if (nq-i > 0)
-	{
-		hh_trafo_complex_kernel_1_SSE_2hv(&q[i], hh, nb, ldq, ldh, s);
-	}
-#endif
+//#else
+//	for (i = 0; i < nq-2; i+=3)
+//	{
+//		hh_trafo_complex_kernel_3_SSE_2hv(&q[i], hh, nb, ldq, ldh, s);
+//	}
+//	if (nq-i > 1)
+//	{
+//		hh_trafo_complex_kernel_2_SSE_2hv(&q[i], hh, nb, ldq, ldh, s);
+//	}
+//	else if (nq-i > 0)
+//	{
+//		hh_trafo_complex_kernel_1_SSE_2hv(&q[i], hh, nb, ldq, ldh, s);
+//	}
+//#endif
 }
 
 static __forceinline void hh_trafo_complex_kernel_4_SSE_2hv(double complex* q, double complex* hh, int nb, int ldq, int ldh, double complex s)
