@@ -10,7 +10,7 @@
 !    - Technische Universität München, Lehrstuhl für Informatik mit
 !      Schwerpunkt Wissenschaftliches Rechnen ,
 !    - Fritz-Haber-Institut, Berlin, Abt. Theorie,
-!    - Max-Plack-Institut für Mathematik in den Naturwissenschaftrn,
+!    - Max-Plack-Institut für Mathematik in den Naturwissenschaften,
 !      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition,
 !      and
 !    - IBM Deutschland GmbH
@@ -109,10 +109,9 @@ contains
 
   subroutine hh_trafo_kernel_24_bgq(q, hh, nb, ldq, ldh, s)
     use precision
+    use elpa_mpi
     implicit none
 
-    include 'mpif.h'
-
     integer(kind=ik), intent(in) :: nb, ldq, ldh
 
     real(kind=rk), intent(inout) :: q(ldq,*)
@@ -317,10 +316,9 @@ contains
 
   subroutine hh_trafo_kernel_16_bgq(q, hh, nb, ldq, ldh, s)
     use precision
+    use elpa_mpi
     implicit none
 
-    include 'mpif.h'
-
     integer(kind=ik), intent(in) :: nb, ldq, ldh
 
     real(kind=rk), intent(inout) :: q(ldq,*)
@@ -475,10 +473,9 @@ contains
 
   subroutine hh_trafo_kernel_8_bgq(q, hh, nb, ldq, ldh, s)
     use precision
+    use elpa_mpi
     implicit none
 
-    include 'mpif.h'
-
     integer(kind=ik), intent(in) :: nb, ldq, ldh
 
     real(kind=rk), intent(inout) :: q(ldq,*)
@@ -582,10 +579,9 @@ contains
 
   subroutine hh_trafo_kernel_4_bgq(q, hh, nb, ldq, ldh, s)
     use precision
+    use elpa_mpi
     implicit none
 
-    include 'mpif.h'
-
     integer(kind=ik), intent(in) :: nb, ldq, ldh
 
     real(kind=rk), intent(inout) :: q(ldq,*)
