@@ -10,7 +10,7 @@
 //    - Technische Universität München, Lehrstuhl für Informatik mit
 //      Schwerpunkt Wissenschaftliches Rechnen ,
 //    - Fritz-Haber-Institut, Berlin, Abt. Theorie,
-//    - Max-Plack-Institut für Mathematik in den Naturwissenschaftrn,
+//    - Max-Plack-Institut für Mathematik in den Naturwissenschaften,
 //      Leipzig, Abt. Komplexe Strukutren in Biologie und Kognition,
 //      and
 //    - IBM Deutschland GmbH
@@ -163,65 +163,67 @@ void quad_hh_trafo_real_sse_4hv(double* q, double* hh, int* pnb, int* pnq, int*
 	}
 }
 
-#if 0
-void quad_hh_trafo_fast_(double* q, double* hh, int* pnb, int* pnq, int* pldq, int* pldh)
-{
-	int i;
-	int nb = *pnb;
-	int nq = *pldq;
-	int ldq = *pldq;
-	int ldh = *pldh;
+//#if 0
+//void quad_hh_trafo_fast_(double* q, double* hh, int* pnb, int* pnq, int* pldq, int* pldh)
+//{
+//	int i;
+//	int nb = *pnb;
+//	int nq = *pldq;
+//	int ldq = *pldq;
+//	int ldh = *pldh;
+//
+//	// calculating scalar products to compute
+//	// 4 householder vectors simultaneously
+//	double s_1_2 = hh[(ldh)+1];
+//	double s_1_3 = hh[(ldh*2)+2];
+//	double s_2_3 = hh[(ldh*2)+1];
+//	double s_1_4 = hh[(ldh*3)+3];
+//	double s_2_4 = hh[(ldh*3)+2];
+//	double s_3_4 = hh[(ldh*3)+1];
+//
+//	// calculate scalar product of first and fourth householder vector
+//	// loop counter = 2
+//	s_1_2 += hh[2-1] * hh[(2+ldh)];
+//	s_2_3 += hh[(ldh)+2-1] * hh[2+(ldh*2)];
+//	s_3_4 += hh[(ldh*2)+2-1] * hh[2+(ldh*3)];
+//
+//	// loop counter = 3
+//	s_1_2 += hh[3-1] * hh[(3+ldh)];
+//	s_2_3 += hh[(ldh)+3-1] * hh[3+(ldh*2)];
+//	s_3_4 += hh[(ldh*2)+3-1] * hh[3+(ldh*3)];
+//
+//	s_1_3 += hh[3-2] * hh[3+(ldh*2)];
+//	s_2_4 += hh[(ldh*1)+3-2] * hh[3+(ldh*3)];
+//
+//	#pragma ivdep
+//	for (i = 4; i < nb; i++)
+//	{
+//		s_1_2 += hh[i-1] * hh[(i+ldh)];
+//		s_2_3 += hh[(ldh)+i-1] * hh[i+(ldh*2)];
+//		s_3_4 += hh[(ldh*2)+i-1] * hh[i+(ldh*3)];
+//
+//		s_1_3 += hh[i-2] * hh[i+(ldh*2)];
+//		s_2_4 += hh[(ldh*1)+i-2] * hh[i+(ldh*3)];
+//
+//		s_1_4 += hh[i-3] * hh[i+(ldh*3)];
+//	}
+//
+//	// Production level kernel calls with padding
+//#ifdef __AVX__
+//	for (i = 0; i < nq; i+=12)
+//	{
+//		hh_trafo_kernel_12_AVX_4hv(&q[i], hh, nb, ldq, ldh, s_1_2, s_1_3, s_2_3, s_1_4, s_2_4, s_3_4);
+//	}
+//#else
+//	for (i = 0; i < nq; i+=6)
+//	{
+//		hh_trafo_kernel_6_SSE_4hv(&q[i], hh, nb, ldq, ldh, s_1_2, s_1_3, s_2_3, s_1_4, s_2_4, s_3_4);
+//	}
+//#endif
+//}
+//#endif
 
-	// calculating scalar products to compute
-	// 4 householder vectors simultaneously
-	double s_1_2 = hh[(ldh)+1];
-	double s_1_3 = hh[(ldh*2)+2];
-	double s_2_3 = hh[(ldh*2)+1];
-	double s_1_4 = hh[(ldh*3)+3];
-	double s_2_4 = hh[(ldh*3)+2];
-	double s_3_4 = hh[(ldh*3)+1];
 
-	// calculate scalar product of first and fourth householder vector
-	// loop counter = 2
-	s_1_2 += hh[2-1] * hh[(2+ldh)];
-	s_2_3 += hh[(ldh)+2-1] * hh[2+(ldh*2)];
-	s_3_4 += hh[(ldh*2)+2-1] * hh[2+(ldh*3)];
-
-	// loop counter = 3
-	s_1_2 += hh[3-1] * hh[(3+ldh)];
-	s_2_3 += hh[(ldh)+3-1] * hh[3+(ldh*2)];
-	s_3_4 += hh[(ldh*2)+3-1] * hh[3+(ldh*3)];
-
-	s_1_3 += hh[3-2] * hh[3+(ldh*2)];
-	s_2_4 += hh[(ldh*1)+3-2] * hh[3+(ldh*3)];
-
-	#pragma ivdep
-	for (i = 4; i < nb; i++)
-	{
-		s_1_2 += hh[i-1] * hh[(i+ldh)];
-		s_2_3 += hh[(ldh)+i-1] * hh[i+(ldh*2)];
-		s_3_4 += hh[(ldh*2)+i-1] * hh[i+(ldh*3)];
-
-		s_1_3 += hh[i-2] * hh[i+(ldh*2)];
-		s_2_4 += hh[(ldh*1)+i-2] * hh[i+(ldh*3)];
-
-		s_1_4 += hh[i-3] * hh[i+(ldh*3)];
-	}
-
-	// Production level kernel calls with padding
-#ifdef __AVX__
-	for (i = 0; i < nq; i+=12)
-	{
-		hh_trafo_kernel_12_AVX_4hv(&q[i], hh, nb, ldq, ldh, s_1_2, s_1_3, s_2_3, s_1_4, s_2_4, s_3_4);
-	}
-#else
-	for (i = 0; i < nq; i+=6)
-	{
-		hh_trafo_kernel_6_SSE_4hv(&q[i], hh, nb, ldq, ldh, s_1_2, s_1_3, s_2_3, s_1_4, s_2_4, s_3_4);
-	}
-#endif
-}
-#endif
 /**
  * Unrolled kernel that computes
  * 6 rows of Q simultaneously, a
